#
# spec file for package verdict
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libverdict1_4

Name:           verdict
Version:        1.4.2
Release:        2.2
Summary:        Compute quality functions of 2 and 3-dimensional regions
License:        BSD-3-Clause
URL:            https://github.com/sandialabs/verdict
Source:         https://github.com/sandialabs/verdict/archive/refs/tags/%{version}.tar.gz#/verdict-%{version}.tar.gz
# PATCH-FIX-UPSTREAM verdict-use-cxx14-standard.patch badshah400@gmail.com -- Use c++14 standard to avoid build failures against gtest >= 1.14
Patch0:         verdict-use-cxx14-standard.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gtest

%description
Verdict is a library for evaluating the geometric qualities of regions of space.

%package -n %{libname}
Summary:        Verdict library for evaluating the geometric qualities of regions of space
Group:          System/Libraries

%description -n %{libname}
Verdict is a library for evaluating the geometric qualities of regions of space.

%package devel
Summary:        Verdict header files
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
This package contains the header files and cmake config files.

%prep
%autosetup -p1

%build
%cmake \
  -DCMAKE_SKIP_RPATH:BOOL=OFF \
  -DCMAKE_CXX_STANDARD:STRING=14 \
  -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
  -DVERDICT_ENABLE_TESTING:BOOL=ON \
  -DCMAKE_INSTALL_DOCDIR=%{_docdir} \
  %{nil}
%cmake_build

%install
%cmake_install
rm -vrf %{buildroot}/%{_docdir}

%check
%ifarch %{ix86}
# https://github.com/sandialabs/verdict/issues/3
export GTEST_FILTER=:-verdict.hex_test3_flat
%endif
%ctest

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%{_libdir}/lib*so.*

%files devel
%doc README.md
%{_includedir}/verdict*.h
%{_libdir}/lib*so
%{_libdir}/cmake/verdict

%changelog
* Thu Apr 25 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add verdict-use-cxx14-standard.patch to build with cpp14
  standard and avoid build failures with gtest >= 1.14.
* Tue Oct 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.2:
  * Add interfaces to some verdict calculations that take double **
  * Implementing length/area calculations and include higher order
    nodes
  * add verdict double ** interface for normalized in-radius
  * More changes to tri normalized inradius to work for dimension 2
  * fix tri normalized inradius to not return nan for collapsd tri
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 1.4.1:
  * VerdictVector: Use c++ headers, re-enable length function
  * Use c++ version of math functions
  * Fix install dir for verdict on Linux.
  * ome fixes for building with the Intel compiler.
  * Fix quad_aspect_ratio for concave quads.
  * Remove unnecessary link to gtest_main
  * improved README
* Wed Oct 19 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Initial package version (1.4.0)
